@@ -9,6 +9,7 @@ from typing import IO, Dict, Iterable, List, Union
 import numpy as np
 import pandas as pd
 import pyarrow as pa
+import pyarrow.parquet as pq
 import smart_open
 from mojap_metadata import Metadata
 from mojap_metadata.converters.arrow_converter import ArrowConverter
@@ -317,13 +318,30 @@ class ArrowParquetWriter(ArrowBaseWriter):
     ) -> None:
         table = pa.Table.from_pandas(next(df), schema=arrow_schema)
 
-        with pa.parquet.ParquetWriter(
+        with pq.ParquetWriter(
             where=output_path, schema=table.schema, **kwargs
         ) as parquet_writer:
             parquet_writer.write_table(table)
             for chunk in df:
                 table = pa.Table.from_pandas(chunk, schema=arrow_schema)
                 parquet_writer.write_table(table)
+        written_arrow_schema = pq.read_schema(output_path)
+        if arrow_schema:
+            mismatched_types = {}
+            for i, written_col in enumerate(written_arrow_schema):
+                schema_col = arrow_schema[i]
+                if not written_col.equals(schema_col):
+                    mismatched_types[written_col.name] = {
+                        "type_in_schema": schema_col.type,
+                        "type_in_written_file": written_col.type,
+                    }
+            if mismatched_types:
+                warnings.warn(
+                    f"""
+                    Arrow has converted the types of some columns.
+                    Consider updating your metadata to match the data more accurately.
+                    {mismatched_types}"""
+                )
 
 
 @dataclass
